/*
 * Code for class CONTAINER [POINTER]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co469.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONTAINER}.compare_objects */
void F439_3057 (EIF_REFERENCE Current)
{
	GTCX
	
	
	*(EIF_BOOLEAN *)(Current + O2736[Dtype(Current)-437]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
}

void EIF_Minit469 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
